@@ -1,6 +1,7 @@
 def main():
     print("Hello py_book_util!")
-    
-if __name__ == '__main__':
+
+
+if __name__ == "__main__":
     # execute only if run as a script
     main()
