@@ -48,7 +48,14 @@ class GitRemoteBook(object):
             self.remote_file,
         )
         util.print_run_cmd('006_cucumber_parallel "%s"' % cucumber_task)
-        util.run_deno_cmd("dos2unix " + self.get_local_path())
+        print("\n")
+        if os.path.isfile(self.get_local_path()):
+            util.run_deno_cmd("dos2unix " + self.get_local_path())
+            util.run_deno_cmd("md5sum " + self.get_local_path())
+            return True
+        else:
+            print("Cannot find %s. Please download again!\n" % self.get_local_path())
+            return False
 
     def upload_file_from_local_dir_to_remote_repo(self):
         cucumber_task = "Upload %s %s to server" % (
