@@ -432,3 +432,20 @@ def find_line_in_file(file_path, line_content, search_line_number_begin=0):
             if line_content == line:
                 return line_number
     return 0
+
+
+def dev_checkout_file(filename):
+    cmd_ret = run_cmd("git log -1 %s" % filename)
+    if cmd_ret == "":
+        if os.path.isfile(filename):
+            os.remove(filename)
+    else:
+        print_run_cmd("git checkout %s" % filename)
+
+
+def dev_show_diff(filename):
+    cmd_ret = run_cmd("git log -1 %s" % filename)
+    if cmd_ret == "":
+        return display_code(filename)
+    else:
+        print_run_cmd("git diff " + filename)
